pub struct DeployAction {
pub private_key: KeySource,
pub fee_private_key: Option<KeySource>,
pub program: String,
pub cannon: CannonId,
pub priority_fee: Option<u64>,
pub fee_record: Option<String>,
}Fields
private_key: KeySourceThe private key to use for the transaction. If not provided, the transaction will be signed with the committee member 0’s key.
fee_private_key: Option<KeySource>A private key to use for the fee. If not provided, the fee will be paid
from the private_key
program: StringThe program to deploy
cannon: CannonIdThe cannon id of who to execute the transaction
priority_fee: Option<u64>The optional priority fee
fee_record: Option<String>The optional fee record for a private fee