BinaryEntry

Struct BinaryEntry 

pub struct BinaryEntry {
    pub source: BinarySource,
    pub sha256: Option<String>,
    pub size: Option<u64>,
}
A BinaryEntry is the location to a binary with an optional shasum

Fields

source: BinarySourcesha256: Option<String>size: Option<u64>

Implementations

Source

impl BinaryEntry

pub fn with_api_path( &self, network: NetworkId, storage_id: InternedId, binary_id: InternedId, ) -> BinaryEntry

pub fn check_sha256(&self) -> bool

Check if the sha256 is a valid sha256 hash

pub fn check_file_size(&self, path: &Path) -> Result<Option<u64>, Error>

Check if the given file has the same size as the size in the BinaryEntry, return the file’s size if it does not match

pub fn check_file_sha256(&self, path: &PathBuf) -> Result<Option<String>, Error>

Check if the given file has the same sha256 as the sha256 in the BinaryEntry, return the file’s sha256 if it does not match