Module constant

Module constant 

Constants

ENV_AGENT_KEY
The environment variable that agents use to authorize with the control plane.
HEADER_AGENT_KEY
The agent key header that is set to ENV_AGENT_KEY.
LEDGER_BASE_DIR
The ledger directory name.
LEDGER_PERSIST_DIR
The directory name for persisted ledgers within the storage dir.
LEDGER_STORAGE_FILE
Temporary storage archive file name.
SNARKOS_FILE
The snarkOS binary file name.
SNARKOS_GENESIS_FILE
The genesis block file name.
SNARKOS_LOG_FILE
The snarkOS log file name.
VERSION_FILE
File containing a version counter for a ledger