Module rpc

Module rpc 

The module defining all RPC behaviors in snops.

This module is split into two separate modules:

  • control: the RPC server that lies on websockets established between the control plane and the agent, and
  • agent: the RPC server that lies on websockets established between the agent and its AOT/snarkOS node.

The naming convention for RPC-related modules is to name the modules after the RPC’s parent, where the parent is the side of the transport responsible for listening for new websocket connections.

Modules

agent
control
error

Structs

RpcTransport

Enums

MuxMessage

Constants

PING_INTERVAL_SEC
PING_LENGTH