Module agent

Module agent 

Modules

node

Structs

AgentNodeServiceClient
The client stub that makes RPC calls to the server. All request methods return Futures.
ServeAgentNodeService
A serving function to use with ::tarpc::server::InFlightRequest::execute.

Enums

AgentNodeServiceRequest
The request sent over the wire from the client to the server.
AgentNodeServiceResponse
The response sent over the wire from the server to the client.

Constants

PING_HEADER

Traits

AgentNodeService
AgentNodeServiceStub
The stub trait for service AgentNodeService.