Module node

Module node 

Structs

NodeServiceClient
The client stub that makes RPC calls to the server. All request methods return Futures.
ServeNodeService
A serving function to use with ::tarpc::server::InFlightRequest::execute.

Enums

NodeServiceRequest
The request sent over the wire from the client to the server.
NodeServiceResponse
The response sent over the wire from the server to the client.

Traits

NodeService
NodeServiceStub
The stub trait for service NodeService.