Module control

Module control 

Modules

agent

Structs

ControlServiceClient
The client stub that makes RPC calls to the server. All request methods return Futures.
ServeControlService
A serving function to use with ::tarpc::server::InFlightRequest::execute.

Enums

ControlServiceRequest
The request sent over the wire from the client to the server.
ControlServiceResponse
The response sent over the wire from the server to the client.

Constants

PING_HEADER

Traits

ControlService
ControlServiceStub
The stub trait for service ControlService.