pub struct AgentServiceClient<Stub = Channel<AgentServiceRequest, AgentServiceResponse>>(/* private fields */);Expand description
The client stub that makes RPC calls to the server. All request methods return Futures.
Implementations
Sourceimpl AgentServiceClient
impl AgentServiceClient
Sourcepub fn new<T>(
config: Config,
transport: T,
) -> NewClient<Self, RequestDispatch<AgentServiceRequest, AgentServiceResponse, T>>
pub fn new<T>( config: Config, transport: T, ) -> NewClient<Self, RequestDispatch<AgentServiceRequest, AgentServiceResponse, T>>
Returns a new client stub that sends requests over the given transport.
Sourceimpl<Stub> AgentServiceClient<Stub>
impl<Stub> AgentServiceClient<Stub>
Sourcepub fn handshake(
&self,
ctx: Context,
handshake: Handshake,
) -> impl Future<Output = Result<Result<(), ReconcileError>, RpcError>> + '_
pub fn handshake( &self, ctx: Context, handshake: Handshake, ) -> impl Future<Output = Result<Result<(), ReconcileError>, RpcError>> + '_
Handshake with some initial connection details.
Sourcepub fn get_addrs(
&self,
ctx: Context,
) -> impl Future<Output = Result<(PortConfig, Option<IpAddr>, Vec<IpAddr>), RpcError>> + '_
pub fn get_addrs( &self, ctx: Context, ) -> impl Future<Output = Result<(PortConfig, Option<IpAddr>, Vec<IpAddr>), RpcError>> + '_
Control plane asks the agent for its external network address, along with local addrs.
Sourcepub fn reconcile(
&self,
ctx: Context,
to: AgentState,
) -> impl Future<Output = Result<Result<(), ReconcileError>, RpcError>> + '_
pub fn reconcile( &self, ctx: Context, to: AgentState, ) -> impl Future<Output = Result<Result<(), ReconcileError>, RpcError>> + '_
Control plane instructs the agent to reconcile towards a particular state.
Sourcepub fn broadcast_tx(
&self,
ctx: Context,
tx: String,
) -> impl Future<Output = Result<Result<(), AgentError>, RpcError>> + '_
pub fn broadcast_tx( &self, ctx: Context, tx: String, ) -> impl Future<Output = Result<Result<(), AgentError>, RpcError>> + '_
Broadcast a transaction locally
Sourcepub fn snarkos_get(
&self,
ctx: Context,
route: String,
) -> impl Future<Output = Result<Result<String, SnarkosRequestError>, RpcError>> + '_
pub fn snarkos_get( &self, ctx: Context, route: String, ) -> impl Future<Output = Result<Result<String, SnarkosRequestError>, RpcError>> + '_
Make a GET request to the snarkos server
Sourcepub fn kill(
&self,
ctx: Context,
) -> impl Future<Output = Result<(), RpcError>> + '_
pub fn kill( &self, ctx: Context, ) -> impl Future<Output = Result<(), RpcError>> + '_
Close the agent process
Locally execute an authorization, using the given query environment id is passed so the agent can determine which aot binary to use
pub fn get_metric( &self, ctx: Context, metric: AgentMetric, ) -> impl Future<Output = Result<f64, RpcError>> + '_
pub fn set_log_level( &self, ctx: Context, level: String, ) -> impl Future<Output = Result<Result<(), AgentError>, RpcError>> + '_
Sourcepub fn find_transaction(
&self,
ctx: Context,
tx_id: String,
) -> impl Future<Output = Result<Result<Option<String>, AgentError>, RpcError>> + '_
pub fn find_transaction( &self, ctx: Context, tx_id: String, ) -> impl Future<Output = Result<Result<Option<String>, AgentError>, RpcError>> + '_
Find a transaction’s block hash by its transaction id
Sourcepub fn get_snarkos_block_lite(
&self,
ctx: Context,
block_hash: String,
) -> impl Future<Output = Result<Result<Option<SnarkOSLiteBlock>, AgentError>, RpcError>> + '_
pub fn get_snarkos_block_lite( &self, ctx: Context, block_hash: String, ) -> impl Future<Output = Result<Result<Option<SnarkOSLiteBlock>, AgentError>, RpcError>> + '_
Get a block info and transaction data from the agent’s running node
pub fn set_aot_log_level( &self, ctx: Context, verbosity: u8, ) -> impl Future<Output = Result<Result<(), AgentError>, RpcError>> + '_
pub fn get_status( &self, ctx: Context, ) -> impl Future<Output = Result<Result<AgentStatus, AgentError>, RpcError>> + '_