DocHeightRequest

Enum DocHeightRequest 

pub enum DocHeightRequest {
    Top,
    Absolute(u32),
    Checkpoint(RetentionSpan),
}
for some reason bincode does not allow deserialize_any so if i want to allow end users to type “top”, 42, or “persist” i need to do have to copies of this where one is not untagged.

bincode. please.

Variants



Top

Use the latest height for the ledger



Absolute(u32)

Set the height to the given block (there must be a checkpoint at this height) Setting to 0 will reset the height to the genesis block



Checkpoint(RetentionSpan)

Use the next checkpoint that matches this checkpoint span