pub enum NodeStatus {
Unknown,
Standby,
PendingStart,
Running(SnarkOSStatus),
Exited(u8),
Stopping,
LedgerWriting,
}Variants
Unknown
The last known status of the node is unknown
Standby
The node can be started and is not currently running
PendingStart
The node waiting on other tasks to complete before starting
Running(SnarkOSStatus)
The node is running
Exited(u8)
The node has exited with a status code
Stopping
The node was online and is in the process of shutting down
LedgerWriting
The node has been stopped and some extra time is needed before it can be started again