Constants
- ENV_
AGENT_ KEY - The environment variable that agents use to authorize with the control plane.
- HEADER_
AGENT_ KEY - The agent key header that is set to
ENV_AGENT_KEY. - LEDGER_
BASE_ DIR - The ledger directory name.
- LEDGER_
PERSIST_ DIR - The directory name for persisted ledgers within the storage dir.
- LEDGER_
STORAGE_ FILE - Temporary storage archive file name.
- SNARKOS_
FILE - The snarkOS binary file name.
- SNARKOS_
GENESIS_ FILE - The genesis block file name.
- SNARKOS_
LOG_ FILE - The snarkOS log file name.
- VERSION_
FILE - File containing a version counter for a ledger