Modules
Structs
- Agent
Node Service Client - The client stub that makes RPC calls to the server. All request methods return Futures.
- Serve
Agent Node Service - A serving function to use with ::tarpc::server::InFlightRequest::execute.
Enums
- Agent
Node Service Request - The request sent over the wire from the client to the server.
- Agent
Node Service Response - The response sent over the wire from the server to the client.
Constants
Traits
- Agent
Node Service - Agent
Node Service Stub - The stub trait for service
AgentNodeService.