Structs
- Node
Service Client - The client stub that makes RPC calls to the server. All request methods return Futures.
- Serve
Node Service - A serving function to use with ::tarpc::server::InFlightRequest::execute.
Enums
- Node
Service Request - The request sent over the wire from the client to the server.
- Node
Service Response - The response sent over the wire from the server to the client.
Traits
- Node
Service - Node
Service Stub - The stub trait for service
NodeService.