Modules
Structs
- Control
Service Client - The client stub that makes RPC calls to the server. All request methods return Futures.
- Serve
Control Service - A serving function to use with ::tarpc::server::InFlightRequest::execute.
Enums
- Control
Service Request - The request sent over the wire from the client to the server.
- Control
Service Response - The response sent over the wire from the server to the client.
Constants
Traits
- Control
Service - Control
Service Stub - The stub trait for service
ControlService.